<template>
    <div class="system-role-container">
        <el-card shadow="hover">
            <div class="system-user-search mb15">
                <div class="basic-line">
                    <span>隐患等级：</span>
                    <el-select class="input-box" v-model="reportData.params.dangerLevel" placeholder="隐患等级" filterable clearable>
                        <el-option v-for="item in dangerLevelList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                    </el-select>
                </div>
                <div class="basic-line">
                    <span>隐患来源：</span>
                    <el-select class="input-box" v-model="reportData.params.dangerSource" placeholder="隐患来源" filterable clearable>
                        <el-option v-for="item in dangerSourceList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                    </el-select>
                </div>
                <div class="basic-line">
                    <span>隐患状态：</span>
                    <el-select class="input-box" v-model="reportData.params.dangerStatus" placeholder="隐患状态" filterable clearable>
                        <el-option v-for="item in dangerStatusList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                    </el-select>
                </div>
                <div class="basic-line">
                    <span>隐患类型：</span>
                    <el-select class="input-box" v-model="reportData.params.dangerType" placeholder="隐患类型" filterable clearable>
                        <el-option v-for="item in dangerTypeList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                    </el-select>
                </div>

                <el-button size="default" type="primary" class="ml10" v-throttle @click="handleSearch">
                    <el-icon>
                        <ele-Search />
                    </el-icon>
                    查询
                </el-button>
                <el-button size="default" type="success" class="ml10" @click="onOpenDialogRef('新增', '')">
                    <el-icon>
                        <ele-FolderAdd />
                    </el-icon>
                    新增隐患
                </el-button>
            </div>
            <el-table :data="reportData.data" style="width: 100%">
                <el-table-column type="index" label="序号" width="60" />
                <el-table-column prop="dangerDesc" label="隐患情况描述" show-overflow-tooltip min-width="150px"></el-table-column>
                <el-table-column prop="produceDeviceName" label="生产装置名称" show-overflow-tooltip min-width="150px"></el-table-column>
                <el-table-column prop="riskUnitName" label="风险分析单元名称" show-overflow-tooltip min-width="150px"></el-table-column>
                <el-table-column prop="dangerSource" label="隐患来源" show-overflow-tooltip min-width="150px">
                    <template #default="scope">
                        {{ parseNumber(scope.row.dangerSource, '隐患来源') }}
                    </template>
                </el-table-column>
                <el-table-column prop="dangerLevel" label="隐患等级" show-overflow-tooltip min-width="150px" align="center">
                    <template #default="scope">
                        <el-tag :type="scope.row.dangerLevel === 1 ? 'warning' : 'danger'">
                            {{ parseNumber(scope.row.dangerLevel, '隐患等级') }}
                        </el-tag>
                    </template>
                </el-table-column>
                <el-table-column prop="dangerType" label="隐患类型" show-overflow-tooltip min-width="150px">
                    <template #default="scope">
                        {{ parseNumber(scope.row.dangerType, '隐患类型') }}
                    </template>
                </el-table-column>
                <el-table-column prop="dangerReason" label="隐患产生原因分析" show-overflow-tooltip min-width="150px"></el-table-column>
                <el-table-column prop="dangerResult" label="隐患可能导致后果" show-overflow-tooltip min-width="150px" align="center">
                    <template #default="scope">
                        <el-tag :type="scope.row.dangerResult === 1 ? 'success' : scope.row.dangerResult === 2 ? 'info' : scope.row.dangerResult === 3 ? 'warning' : 'danger'"> {{ parseNumber(scope.row.dangerResult, '隐患可能导致后果') }}</el-tag>
                    </template>
                </el-table-column>
                <el-table-column prop="createByUserName" label="创建人" show-overflow-tooltip min-width="150px"></el-table-column>
                <el-table-column prop="gmtCreate" label="创建时间" show-overflow-tooltip min-width="200px"></el-table-column>
                <el-table-column prop="lastEditUserName" label="最后修改人" show-overflow-tooltip min-width="150px"></el-table-column>
                <el-table-column prop="gmtModitify" label="最后修改时间" show-overflow-tooltip min-width="200px"></el-table-column>
                <el-table-column label="操作" width="250" fixed="right" align="center">
                    <template #default="scope">
                        <el-button size="small" text type="primary" :icon="View" @click="onOpenDialogRef('查看', scope.row)">查看</el-button>
                        <el-button size="small" text type="primary" :icon="Edit" @click="onOpenDialogRef('修改', scope.row)">修改</el-button>
                        <el-button size="small" text type="danger" :icon="Delete" @click="onDelProductionDevice(scope.row)">删除</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br />
            <el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" :pager-count="5" :page-sizes="[10, 15, 20, 30]" v-model:current-page="reportData.params.pageIndex" background v-model:page-size="reportData.params.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="reportData.total" class="page-position"> </el-pagination>
            <br />
            <br />
        </el-card>
        <reportDialog ref="reportDialogRef" @refreshReport="initReportTableData" />
    </div>
</template>

<script lang="ts">
import { toRefs, reactive, onMounted, ref, defineComponent } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import reportDialog from './components/reportDialog.vue';
import { Edit, Delete, View } from '@element-plus/icons-vue';
import { hiddenReportApi } from '/@/api/doublePreventSystem/report';
import { departmentApi } from '/@/api/systemManage/department';
import { productionDeviceApi } from '/@/api/doublePreventSystem/productionDevice';
import { safetyRiskAnalyseUnitApi } from '/@/api/doublePreventSystem/safetyRiskAnalyseUnit';

// 定义接口来定义对象的类型
interface TableData {
    quota: string;
    quotaUnit: string;
    quotaType: string;
    createUserName: string;
    gmtCreate: string;
    lastEditUserName: string;
    gmtModitify: string;
}
interface TableDataState {
    reportData: {
        data: Array<TableData>;
        total: number;
        loading: boolean;
        params: {
            pageIndex: number;
            pageSize: number;
            dangerLevel: number | null;
            dangerSource: number | null;
            dangerStatus: string | null;
            dangerType: number | null;
        };
    };
    dangerLevelList: Array<enumType>;
    dangerSourceList: Array<enumType>;
    dangerStatusList: Array<enumType>;
    dangerTypeList: Array<enumType>;
    dangerResultList: Array<enumType>;
    departmentList: [];
    allProduceDeviceData: [];
    allSafetyRiskUnitData: [];
}
interface enumType {
    id: number;
    name: string;
}

export default defineComponent({
    name: 'report',
    components: { reportDialog, Edit, Delete, View },
    setup() {
        const reportDialogRef = ref();
        const state = reactive<TableDataState>({
            reportData: {
                data: [],
                total: 0,
                loading: false,
                params: {
                    pageIndex: 1,
                    pageSize: 15,
                    dangerLevel: null,
                    dangerSource: null,
                    dangerStatus: null,
                    dangerType: null
                }
            },
            departmentList: [],
            dangerLevelList: [
                { id: 1, name: '一般隐患' },
                { id: 2, name: '重大隐患' }
            ],
            dangerSourceList: [
                { id: 1, name: '日常排查' },
                { id: 2, name: '综合性排查' },
                { id: 3, name: '专业性排查' },
                { id: 4, name: '季节性排查' },
                { id: 5, name: '重点时段及节假日前排查' },
                { id: 6, name: '事故类比排查' },
                { id: 7, name: '复产复工前排查' },
                { id: 8, name: '外聘专家诊断式排查' },
                { id: 9, name: '管控措施失效' },
                { id: 10, name: '其他' }
            ],
            dangerStatusList: [
                { id: 0, name: '整改中' },
                { id: 1, name: '待验收' },
                { id: 2, name: '延期整改' },
                { id: 4, name: '超期未整改' },
                { id: 9, name: '已验收' }
            ],
            dangerTypeList: [
                { id: 1, name: '安全' },
                { id: 2, name: '工艺' },
                { id: 3, name: '电气' },
                { id: 4, name: '仪表' },
                { id: 5, name: '消防' },
                { id: 6, name: '总图' },
                { id: 7, name: '设备' },
                { id: 8, name: '其他' }
            ],
            dangerResultList: [
                { id: 1, name: '无' },
                { id: 2, name: '轻伤' },
                { id: 3, name: '重伤' },
                { id: 4, name: '死亡' }
            ],
            allProduceDeviceData: [],
            allSafetyRiskUnitData: []
        });

        // 初始化表格数据
        const initReportTableData = async () => {
            let res = await hiddenReportApi().getHiddenReportList(state.reportData.params);
            if (res.data.code === '200') {
                state.reportData.data = res.data.data;
                state.reportData.total = res.data.count;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        //获取生产装置列表
        const getAllProduceDeviceData = async () => {
            let res = await productionDeviceApi().getAllProductionDeviceList();
            if (res.data.code === '200') {
                state.allProduceDeviceData = res.data.data;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        // 获取安全风险分析单元数据
        const getAllSafetyRiskEventData = async () => {
            let res = await safetyRiskAnalyseUnitApi().getAllSafetyRiskAnalyseUnitList();
            if (res.data.code === '200') {
                state.allSafetyRiskUnitData = JSON.parse(JSON.stringify(res.data.data));
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        //获取部门列表
        const getDepartmentData = async () => {
            let res = await departmentApi().getDepartmentList();
            if (res.data.code === '200') {
                state.departmentList = res.data.data;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        // 打开弹窗
        const onOpenDialogRef = (type: string, value: any) => {
            reportDialogRef.value.openReportDialog(type, value, state.departmentList, state.allProduceDeviceData, state.allSafetyRiskUnitData);
        };
        // 删除
        const onDelProductionDevice = (row: any) => {
            ElMessageBox.confirm(`此操作将永久该条隐患，是否继续?`, '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning'
            })
                .then(async () => {
                    let res = await hiddenReportApi().deleteHiddenReport({ id: row.id });
                    if (res.data.code === '200') {
                        ElMessage({
                            type: 'success',
                            duration: 2000,
                            message: '删除成功'
                        });
                        await initReportTableData();
                    } else {
                        ElMessage({
                            type: 'warning',
                            message: res.data.msg
                        });
                    }
                })
                .catch(() => {});
        };

        const handleSearch = () => {
            initReportTableData();
        };
        // 分页改变
        const onHandleSizeChange = (val: number) => {
            state.reportData.params.pageSize = val;
            initReportTableData();
        };
        // 分页改变
        const onHandleCurrentChange = (val: number) => {
            state.reportData.params.pageIndex = val;
            initReportTableData();
        };

        const parseNumber = (value: string | number, type: string) => {
            if (type === '隐患来源') {
                return state.dangerSourceList.find((item) => item.id === value)?.name;
            } else if (type === '隐患等级') {
                return state.dangerLevelList.find((item) => item.id === value)?.name;
            } else if (type === '隐患类型') {
                return state.dangerTypeList.find((item) => item.id === value)?.name;
            } else {
                return state.dangerResultList.find((item) => item.id === value)?.name;
            }
        };

        // 页面加载时
        onMounted(() => {
            initReportTableData();
            getDepartmentData();
            getAllProduceDeviceData();
            getAllSafetyRiskEventData();
        });

        return {
            Edit,
            View,
            Delete,
            parseNumber,
            handleSearch,
            onOpenDialogRef,
            onHandleSizeChange,
            onDelProductionDevice,
            onHandleCurrentChange,
            reportDialog,
            reportDialogRef,
            initReportTableData,
            ...toRefs(state)
        };
    }
});
</script>

<style scoped></style>
